
dialogId("del-v-dve", "font_big", "See? This ship had two gun decks. It must have been a man-of-war. The acrid smell of gunpowder still seems to linger in the air...")
dialogStr("Zie je dat? Dit schip had twee kanonsdekken. Het was vast een oorlogsschip. De geur van buskruit hangt hier nogsteeds in de lucht...")


dialogId("del-m-voda", "font_small", "You mean, in the water.")
dialogStr("Je bedoelt \"in het water\".")


dialogId("del-m-ci", "font_small", "Whose ship was she? Maybe she served under admiral Nelson... or captain Hornblower.")
dialogStr("Van wie was dit schip? Misschien was het onderdeel van de vloot van admiraal Nelson... of van kapitein Hornblower.")


dialogId("del-v-splet", "font_big", "No, I think you’re about a hundred years off.")
dialogStr("Nee, ik denk dat je er ongeveer honderd jaar naast zit.")


dialogId("del-v-mec", "font_big", "I have a feeling we’re going to need that sword.")
dialogStr("Ik heb het gevoel dat we dat zwaard nodig gaan hebben.")


dialogId("del-m-tus", "font_small", "You and your ‘feelings’. Besides, we’re not supposed to be giving any hints.")
dialogStr("Jij en je gevoel ook altijd. En we hadden toch besloten geen aanwijzingen te geven.")


dialogId("del-m-jedn0", "font_small", "That was a little too simple, wasn’t it?")
dialogStr("Dat was wel erg simpel, vind je niet?")


dialogId("del-m-jedn1", "font_small", "Could it possibly be so simple?")
dialogStr("Zou het echt zo simpel kunnen zijn?")


dialogId("del-m-jedn2", "font_small", "There must be some kind of mistake.")
dialogStr("Hier klopt iets niet.")

